@@ -12,47 +12,51 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Pythonic FP - FP tools for functions
-
-Not a replacement for the std library's `functools` which is more about
-modifying function behavior through decorators than functional composition
-and application.
+"""
+FP tools for functions
+======================
 
 FP utilities to manipulate and partially apply functions
 
 - *function* **swap** - Swap the arguments of a 2 argument function
-- *function* **it** - Function returning an iterator of its arguments
 - *function* **sequenced** - Convert function to take a sequence of its arguments
 - *function* **negate** - Transforms a predicate to its negation
 - *function* **partial** - Returns a partially applied function
 
 """
 
-from __future__ import annotations
-from collections.abc import Callable, Iterator
-from typing import Any, ParamSpec, TypeVar
+from collections.abc import Callable
+from typing import Any, ParamSpec
 
-__all__ = ['swap', 'sequenced', 'partial', 'it', 'negate']
+__all__ = ['swap', 'sequenced', 'partial', 'negate']
 
-A = TypeVar('A')    # Needed only for pdoc documentation generation. Otherwise,
-R = TypeVar('R')    # ignored by both MyPy and Python. Makes linters unhappy
-U = TypeVar('U')    # when these are used on function and method signatures due
-V = TypeVar('V')    # to "redefined-outer-name" warnings. Function and method
-P = ParamSpec('P')  # signatures do not support variance and bounds constraints.
+P = ParamSpec('P')
 
 
 def swap[U, V, R](f: Callable[[U, V], R]) -> Callable[[V, U], R]:
-    """Swap arguments of a two argument function."""
+    """
+    Swap args
+    ---------
+
+    Swap arguments of a two argument function.
+
+    :param f: Two argument function.
+    :returns: A version of ``f`` with its arguments swapped.
+
+    """
     return lambda v, u: f(u, v)
 
 
-def it[A](*args: A) -> Iterator[A]:
-    """Function returning an iterator of its arguments."""
-    yield from args
-
-
 def negate[**P](f: Callable[P, bool]) -> Callable[P, bool]:
-    """Take a predicate and return its negation."""
+    """
+    Negate predicate
+    ----------------
+
+    Take a predicate and return its negation.
+
+    :param f: a function ``f`` which returns a bool
+    :returns: the function ``not f``
+    """
 
     def ff(*args: P.args, **kwargs: P.kwargs) -> bool:
         return not f(*args, **kwargs)
@@ -61,7 +65,11 @@ def negate[**P](f: Callable[P, bool]) -> Callable[P, bool]:
 
 
 def sequenced[R](f: Callable[..., R]) -> Callable[[tuple[Any]], R]:
-    """Convert a function with arbitrary positional arguments to one taking
+    """
+    Multi-to-single valued
+    ----------------------
+
+    Convert a function with arbitrary positional arguments to one taking
     a tuple of the original arguments.
 
     - was awaiting typing and mypy "improvements" to ParamSpec
@@ -69,11 +77,10 @@ def sequenced[R](f: Callable[..., R]) -> Callable[[tuple[Any]], R]:
       - return type: Callable[tuple[P.args], R]   ???
       - return type: Callable[[tuple[P.args]], R] ???
 
-    - not going to happen, `see <https://github.com/python/mypy/pull/18278>`_
-
     TODO: Look into replacing this function with a Callable class?
 
     """
+
     def ff(tupled_args: tuple[Any]) -> R:
         return f(*tupled_args)
 
@@ -81,12 +88,17 @@ def sequenced[R](f: Callable[..., R]) -> Callable[[tuple[Any]], R]:
 
 
 def partial[**P, R](f: Callable[P, R], *args: Any) -> Callable[..., R]:
-    """Partially apply arguments to a function, left to right.
+    """
+    Partial application
+    -------------------
+
+    Partially apply arguments to a function, left to right.
 
     - type-wise the only thing guaranteed is the return type
     - best practice is to cast the result immediately
 
     """
+
     def finish(*rest: Any) -> R:
         return sequenced(f)(args + rest)
 
